@@ -1,13 +1,14 @@
 import logging
 import os
 import sys
+from pathlib import Path
 
 from cleo import Application, Command
+from rich.live import Live
+from rich.logging import RichHandler
 
 from rabbit import __version__
-from rabbit.cli import Consumer, Producer
-
-logging.basicConfig(level=logging.DEBUG)
+from rabbit.cli import Consumer, Publisher
 
 
 class ConsumerCommand(Command):
@@ -24,19 +25,28 @@ class ConsumerCommand(Command):
     """
 
     def handle(self):
-        self.line("<info>>></info> <options=bold>starting consumer...</>")
-        consumer = Consumer(
-            exchange_name=os.getenv("SUBSCRIBE_EXCHANGE_NAME", self.option("exchange")),
-            exchange_type=os.getenv("SUBSCRIBE_EXCHANGE_TYPE", self.option("type")),
-            exchange_topic=os.getenv("SUBSCRIBE_TOPIC", self.option("key")),
-            queue_name=os.getenv("SUBSCRIBE_QUEUE_NAME", self.option("queue")),
-            concurrent=int(self.option("concurrent")),
+        logging.basicConfig(
+            level="NOTSET",
+            format="%(message)s",
+            datefmt="[%X]",
+            handlers=[RichHandler(show_path=False)],
         )
-        try:
-            consumer.run(self.argument("chaos"))
-        except KeyboardInterrupt:
-            self.line("<info>!></info> <options=bold>consumer finished!</>")
-            raise SystemExit
+        with Live(refresh_per_second=1, auto_refresh=False) as live:
+            live.console.print("Running consumer...")
+            consumer = Consumer(
+                exchange_name=os.getenv(
+                    "SUBSCRIBE_EXCHANGE_NAME", self.option("exchange")
+                ),
+                exchange_type=os.getenv("SUBSCRIBE_EXCHANGE_TYPE", self.option("type")),
+                exchange_topic=os.getenv("SUBSCRIBE_TOPIC", self.option("key")),
+                queue_name=os.getenv("SUBSCRIBE_QUEUE_NAME", self.option("queue")),
+                concurrent=int(self.option("concurrent")),
+            )
+            try:
+                consumer.run(self.argument("chaos"))
+            except KeyboardInterrupt:
+                self.line("<info>!></info> <options=bold>consumer finished!</>")
+                raise SystemExit
 
 
 class EventCommand(Command):
@@ -51,27 +61,26 @@ class EventCommand(Command):
         {--host=localhost : rabbit hostname.}
         {--port=5672 : rabbit port.}
         {--login=guest : rabbit login.}
-        {--pass=guest : rabbit password.}
+        {--password=guest : rabbit password.}
         {--ssl : enable rabbit ssl connection.}
         {--verify : verify ssl certificate?.}
         {--channels=1 : channel max.}
     """
 
     def handle(self):
-        self.line(
-            f"<info>>></info> <options=bold>sending event to: "
-            f"[exchange: {os.getenv('PUBLISH_EXCHANGE_NAME', self.option('exchange'))}"
-            f" | key: {os.getenv('PUBLISH_ROUTING_KEY', self.option('key'))}"
-            f" | events: {self.option('events')}]</>"
-        )
-        try:
-            with open(f"{self.argument('payload')}", "rb") as f:
-                payload = f.read()
-        except FileNotFoundError:
+        if self.io.verbosity:
+            self.line(
+                f"<info>>></info> <options=bold>"
+                f"[exchange: {os.getenv('PUBLISH_EXCHANGE_NAME', self.option('exchange'))}"
+                f" | key: {os.getenv('PUBLISH_ROUTING_KEY', self.option('key'))}"
+                f" | events: {self.option('events')}]</>"
+            )
+        if not Path(f"{self.argument('payload')}").exists():
             self.line(f"<error>File not found: {self.argument('payload')}</error>")
             sys.exit(1)
+        payload = Path(f"{self.argument('payload')}").read_bytes()
         try:
-            prod = Producer(
+            prod = Publisher(
                 payload,
                 qtd=int(self.option("events")),
                 exchange_name=os.getenv(
@@ -81,7 +90,7 @@ class EventCommand(Command):
                 host=self.option("host"),
                 port=self.option("port"),
                 login=self.option("login"),
-                password=self.option("pass"),
+                password=self.option("password"),
                 ssl=self.option("ssl"),
                 verify_ssl=self.option("verify"),
                 channel_max=int(self.option("channels")),
