@@ -5,7 +5,7 @@ import random
 from .logger import logger
 
 
-async def async_echo_job(data: bytes) -> bytes:
+async def async_echo_job(data: bytes, *args, **kwargs) -> bytes:
     """async simple job."""
     await asyncio.sleep(random.randint(5, 10))
     logger.warning("Using the standard callable to process subscribe events.")
@@ -14,7 +14,7 @@ async def async_echo_job(data: bytes) -> bytes:
     return bytes(json.dumps(data_response), "utf-8")
 
 
-async def async_chaos_job(data: bytes) -> bytes:
+async def async_chaos_job(data: bytes, *args, **kwargs) -> bytes:
     """async chaos job."""
     if random.choice([True, False]):
         await asyncio.sleep(random.randint(5, 10))
